﻿using System;
using System.Collections.Generic;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata;

namespace rkismvvm
{
    public partial class TaskHelpContext : DbContext
    {
        public TaskHelpContext()
        {
        }

        public TaskHelpContext(DbContextOptions<TaskHelpContext> options)
            : base(options)
        {
        }

        public virtual DbSet<StatusTask> StatusTasks { get; set; } = null!;
        public virtual DbSet<Task> Tasks { get; set; } = null!;
        public virtual DbSet<User> Users { get; set; } = null!;

        protected override void OnConfiguring(DbContextOptionsBuilder optionsBuilder)
        {
            optionsBuilder.UseLazyLoadingProxies();
            if (!optionsBuilder.IsConfigured)
            {
                optionsBuilder.UseSqlServer("Data Source=(localdb)\\mssqllocaldb; Initial Catalog=TaskHelp;Trusted_Connection=True;");

            }
        }

        protected override void OnModelCreating(ModelBuilder modelBuilder)
        {
            modelBuilder.Entity<StatusTask>(entity =>
            {
                
                entity.ToTable("StatusTask");

                entity.Property(e => e.StatusTaskId)
                    .ValueGeneratedNever()
                    .HasColumnName("StatusTaskID");

                entity.Property(e => e.StatusName).HasMaxLength(20);
            });

            modelBuilder.Entity<Task>(entity =>
            {
                entity.ToTable("Task");

                entity.Property(e => e.TaskId)
                    .ValueGeneratedNever()
                    .HasColumnName("TaskID");

                entity.Property(e => e.StatusTaskId).HasColumnName("StatusTaskID");

                entity.Property(e => e.TaskDate).HasColumnType("datetime");

                entity.Property(e => e.TaskName).HasMaxLength(50);

                entity.Property(e => e.UserGiveId).HasColumnName("UserGiveID");

                entity.Property(e => e.UserTakeId).HasColumnName("UserTakeID");

                entity.HasOne(d => d.StatusTask)
                    .WithMany(p => p.Tasks)
                    .HasForeignKey(d => d.StatusTaskId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_Task_StatusTask");

                entity.HasOne(d => d.UserGive)
                    .WithMany(p => p.TaskUserGives)
                    .HasForeignKey(d => d.UserGiveId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_Task_User");

                entity.HasOne(d => d.UserTake)
                    .WithMany(p => p.TaskUserTakes)
                    .HasForeignKey(d => d.UserTakeId)
                    .OnDelete(DeleteBehavior.ClientSetNull)
                    .HasConstraintName("FK_Task_User1");
            });

            modelBuilder.Entity<User>(entity =>
            {
                entity.HasKey(e => e.UserId);
                entity.ToTable("User");

                entity.Property(e => e.UserId)
                    .ValueGeneratedNever()
                    .HasColumnName("UserID");

                entity.Property(e => e.LastName).HasMaxLength(50);

                entity.Property(e => e.Login).HasMaxLength(20);

                entity.Property(e => e.MiddleName).HasMaxLength(50);

                entity.Property(e => e.Name).HasMaxLength(50);

                entity.Property(e => e.Password).HasMaxLength(20);

                entity.Property(e => e.PhoneNum)
                    .HasMaxLength(11)
                    .IsFixedLength();
            });

            OnModelCreatingPartial(modelBuilder);
        }

        partial void OnModelCreatingPartial(ModelBuilder modelBuilder);
    }
}
